@@ -1,19 +1,19 @@
 /*
  * libev simple C++ wrapper classes
  *
- * Copyright (c) 2007,2008 Marc Alexander Lehmann <libev@schmorp.de>
+ * Copyright (c) 2007,2008,2010 Marc Alexander Lehmann <libev@schmorp.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modifica-
  * tion, are permitted provided that the following conditions are met:
- * 
+ *
  *   1.  Redistributions of source code must retain the above copyright notice,
  *       this list of conditions and the following disclaimer.
- * 
+ *
  *   2.  Redistributions in binary form must reproduce the above copyright
  *       notice, this list of conditions and the following disclaimer in the
  *       documentation and/or other materials provided with the distribution.
- * 
+ *
  * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
  * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MER-
  * CHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
@@ -58,13 +58,15 @@ namespace ev {
 
   typedef ev_tstamp tstamp;
 
-  enum
-  {
+  enum {
     UNDEF    = EV_UNDEF,
     NONE     = EV_NONE,
     READ     = EV_READ,
     WRITE    = EV_WRITE,
+#if EV_COMPAT3
     TIMEOUT  = EV_TIMEOUT,
+#endif
+    TIMER    = EV_TIMER,
     PERIODIC = EV_PERIODIC,
     SIGNAL   = EV_SIGNAL,
     CHILD    = EV_CHILD,
@@ -76,7 +78,7 @@ namespace ev {
     ASYNC    = EV_ASYNC,
     EMBED    = EV_EMBED,
 #   undef ERROR // some systems stupidly #define ERROR
-    ERROR    = EV_ERROR,
+    ERROR    = EV_ERROR
   };
 
   enum
@@ -95,14 +97,18 @@ namespace ev {
 
   enum
   {
+#if EV_COMPAT3
     NONBLOCK = EVLOOP_NONBLOCK,
-    ONESHOT  = EVLOOP_ONESHOT
+    ONESHOT  = EVLOOP_ONESHOT,
+#endif
+    NOWAIT   = EVRUN_NOWAIT,
+    ONCE     = EVRUN_ONCE
   };
 
   enum how_t
   {
-    ONE = EVUNLOOP_ONE,
-    ALL = EVUNLOOP_ALL
+    ONE = EVBREAK_ONE,
+    ALL = EVBREAK_ALL
   };
 
   struct bad_loop
@@ -162,24 +168,14 @@ namespace ev {
     }
 
 #if EV_MULTIPLICITY
-    bool operator == (struct ev_loop *other) const throw ()
+    bool operator == (const EV_P) const throw ()
     {
-      return this->EV_AX == other;
+      return this->EV_AX == EV_A;
     }
 
-    bool operator != (struct ev_loop *other) const throw ()
+    bool operator != (const EV_P) const throw ()
     {
-      return ! (*this == other);
-    }
-
-    bool operator == (const struct ev_loop *other) const throw ()
-    {
-      return this->EV_AX == other;
-    }
-
-    bool operator != (const struct ev_loop *other) const throw ()
-    {
-      return (*this == other);
+      return (*this == EV_A);
     }
 
     operator struct ev_loop * () const throw ()
@@ -198,28 +194,31 @@ namespace ev {
     }
 #endif
 
+#if EV_COMPAT3
     void loop (int flags = 0)
     {
-      ev_loop (EV_AX_ flags);
+      ev_run (EV_AX_ flags);
     }
 
     void unloop (how_t how = ONE) throw ()
     {
-      ev_unloop (EV_AX_ how);
+      ev_break (EV_AX_ how);
+    }
+#endif
+
+    void run (int flags = 0)
+    {
+      ev_run (EV_AX_ flags);
+    }
+
+    void break_loop (how_t how = ONE) throw ()
+    {
+      ev_break (EV_AX_ how);
     }
 
     void post_fork () throw ()
     {
-#if EV_MULTIPLICITY
       ev_loop_fork (EV_AX);
-#else
-      ev_default_fork ();
-#endif
-    }
-
-    unsigned int count () const throw ()
-    {
-      return ev_loop_count (EV_AX);
     }
 
     unsigned int backend () const throw ()
@@ -242,6 +241,17 @@ namespace ev {
       ev_unref (EV_AX);
     }
 
+#if EV_FEATURE_API
+    unsigned int iteration () const throw ()
+    {
+      return ev_iteration (EV_AX);
+    }
+
+    unsigned int depth () const throw ()
+    {
+      return ev_depth (EV_AX);
+    }
+
     void set_io_collect_interval (tstamp interval) throw ()
     {
       ev_set_io_collect_interval (EV_AX_ interval);
@@ -251,9 +261,10 @@ namespace ev {
     {
       ev_set_timeout_collect_interval (EV_AX_ interval);
     }
+#endif
 
     // function callback
-    void once (int fd, int events, tstamp timeout, void (*cb)(int, void *), void* arg = 0) throw ()
+    void once (int fd, int events, tstamp timeout, void (*cb)(int, void *), void *arg = 0) throw ()
     {
       ev_once (EV_AX_ fd, events, timeout, cb, arg);
     }
@@ -265,28 +276,21 @@ namespace ev {
       once (fd, events, timeout, method_thunk<K, method>, object);
     }
 
+    // default method == operator ()
+    template<class K>
+    void once (int fd, int events, tstamp timeout, K *object) throw ()
+    {
+      once (fd, events, timeout, method_thunk<K, &K::operator ()>, object);
+    }
+
     template<class K, void (K::*method)(int)>
-    static void method_thunk (int revents, void* arg)
+    static void method_thunk (int revents, void *arg)
     {
-      K *obj = static_cast<K *>(arg);
-      (obj->*method) (revents);
+      static_cast<K *>(arg)->*method
+        (revents);
     }
 
-    // const method callback
-    template<class K, void (K::*method)(int) const>
-    void once (int fd, int events, tstamp timeout, const K *object) throw ()
-    {
-      once (fd, events, timeout, const_method_thunk<K, method>, object);
-    }
-
-    template<class K, void (K::*method)(int) const>
-    static void const_method_thunk (int revents, void* arg)
-    {
-      K *obj = static_cast<K *>(arg);
-      (obj->*method) (revents);
-    }
-
-    // simple method callback
+    // no-argument method callback
     template<class K, void (K::*method)()>
     void once (int fd, int events, tstamp timeout, K *object) throw ()
     {
@@ -294,10 +298,10 @@ namespace ev {
     }
 
     template<class K, void (K::*method)()>
-    static void method_noargs_thunk (int revents, void* arg)
+    static void method_noargs_thunk (int revents, void *arg)
     {
-      K *obj = static_cast<K *>(arg);
-      (obj->*method) ();
+      static_cast<K *>(arg)->*method
+        ();
     }
 
     // simpler function callback
@@ -308,9 +312,10 @@ namespace ev {
     }
 
     template<void (*cb)(int)>
-    static void simpler_func_thunk (int revents, void* arg)
+    static void simpler_func_thunk (int revents, void *arg)
     {
-      (*cb) (revents);
+      (*cb)
+        (revents);
     }
 
     // simplest function callback
@@ -321,9 +326,10 @@ namespace ev {
     }
 
     template<void (*cb)()>
-    static void simplest_func_thunk (int revents, void* arg)
+    static void simplest_func_thunk (int revents, void *arg)
     {
-      (*cb) ();
+      (*cb)
+        ();
     }
 
     void feed_fd_event (int fd, int revents) throw ()
@@ -385,11 +391,6 @@ namespace ev {
         throw bad_loop ();
     }
 
-    ~default_loop () throw ()
-    {
-      ev_default_destroy ();
-    }
-
   private:
     default_loop (const default_loop &);
     default_loop &operator = (const default_loop &);
@@ -423,7 +424,8 @@ namespace ev {
     #if EV_MULTIPLICITY
       EV_PX;
 
-      void set (EV_PX) throw ()
+      // loop set
+      void set (EV_P) throw ()
       {
         this->EV_A = EV_A;
       }
@@ -437,40 +439,12 @@ namespace ev {
       ev_init (this, 0);
     }
 
-    void set_ (void *data, void (*cb)(EV_P_ ev_watcher *w, int revents)) throw ()
+    void set_ (const void *data, void (*cb)(EV_P_ ev_watcher *w, int revents)) throw ()
     {
-      this->data = data;
+      this->data = (void *)data;
       ev_set_cb (static_cast<ev_watcher *>(this), cb);
     }
 
-    // method callback
-    template<class K, void (K::*method)(watcher &w, int)>
-    void set (K *object) throw ()
-    {
-      set_ (object, method_thunk<K, method>);
-    }
-
-    template<class K, void (K::*method)(watcher &w, int)>
-    static void method_thunk (EV_P_ ev_watcher *w, int revents)
-    {
-      K *obj = static_cast<K *>(w->data);
-      (obj->*method) (*static_cast<watcher *>(w), revents);
-    }
-
-    // const method callback
-    template<class K, void (K::*method)(watcher &w, int) const>
-    void set (const K *object) throw ()
-    {
-      set_ (object, const_method_thunk<K, method>);
-    }
-
-    template<class K, void (K::*method)(watcher &w, int) const>
-    static void const_method_thunk (EV_P_ ev_watcher *w, int revents)
-    {
-      K *obj = static_cast<K *>(w->data);
-      (static_cast<K *>(w->data)->*method) (*static_cast<watcher *>(w), revents);
-    }
-
     // function callback
     template<void (*function)(watcher &w, int)>
     void set (void *data = 0) throw ()
@@ -481,10 +455,32 @@ namespace ev {
     template<void (*function)(watcher &w, int)>
     static void function_thunk (EV_P_ ev_watcher *w, int revents)
     {
-      function (*static_cast<watcher *>(w), revents);
+      function
+        (*static_cast<watcher *>(w), revents);
     }
 
-    // simple callback
+    // method callback
+    template<class K, void (K::*method)(watcher &w, int)>
+    void set (K *object) throw ()
+    {
+      set_ (object, method_thunk<K, method>);
+    }
+
+    // default method == operator ()
+    template<class K>
+    void set (K *object) throw ()
+    {
+      set_ (object, method_thunk<K, &K::operator ()>);
+    }
+
+    template<class K, void (K::*method)(watcher &w, int)>
+    static void method_thunk (EV_P_ ev_watcher *w, int revents)
+    {
+      (static_cast<K *>(w->data)->*method)
+        (*static_cast<watcher *>(w), revents);
+    }
+
+    // no-argument callback
     template<class K, void (K::*method)()>
     void set (K *object) throw ()
     {
@@ -494,14 +490,15 @@ namespace ev {
     template<class K, void (K::*method)()>
     static void method_noargs_thunk (EV_P_ ev_watcher *w, int revents)
     {
-      K *obj = static_cast<K *>(w->data);
-      (obj->*method) ();
+      (static_cast<K *>(w->data)->*method)
+        ();
     }
 
     void operator ()(int events = EV_UNDEF)
     {
-      return ev_cb (static_cast<ev_watcher *>(this))
-        (static_cast<ev_watcher *>(this), events);
+      return
+        ev_cb (static_cast<ev_watcher *>(this))
+          (static_cast<ev_watcher *>(this), events);
     }
 
     bool is_active () const throw ()
@@ -520,9 +517,9 @@ namespace ev {
     }
   };
 
-  inline tstamp now () throw ()
+  inline tstamp now (EV_P) throw ()
   {
-    return ev_time ();
+    return ev_now (EV_A);
   }
 
   inline void delay (tstamp interval) throw ()
@@ -657,6 +654,11 @@ namespace ev {
     {
       ev_timer_again (EV_A_ static_cast<ev_timer *>(this));
     }
+
+    ev_tstamp remaining ()
+    {
+      return ev_timer_remaining (EV_A_ static_cast<ev_timer *>(this));
+    }
   EV_END_WATCHER (timer, timer)
 
   #if EV_PERIODIC_ENABLE
@@ -682,6 +684,7 @@ namespace ev {
   EV_END_WATCHER (periodic, periodic)
   #endif
 
+  #if EV_SIGNAL_ENABLE
   EV_BEGIN_WATCHER (sig, signal)
     void set (int signum) throw ()
     {
@@ -697,7 +700,9 @@ namespace ev {
       start ();
     }
   EV_END_WATCHER (sig, signal)
+  #endif
 
+  #if EV_CHILD_ENABLE
   EV_BEGIN_WATCHER (child, child)
     void set (int pid, int trace = 0) throw ()
     {
@@ -713,6 +718,7 @@ namespace ev {
       start ();
     }
   EV_END_WATCHER (child, child)
+  #endif
 
   #if EV_STAT_ENABLE
   EV_BEGIN_WATCHER (stat, stat)
@@ -738,17 +744,23 @@ namespace ev {
   EV_END_WATCHER (stat, stat)
   #endif
 
+  #if EV_IDLE_ENABLE
   EV_BEGIN_WATCHER (idle, idle)
     void set () throw () { }
   EV_END_WATCHER (idle, idle)
+  #endif
 
+  #if EV_PREPARE_ENABLE
   EV_BEGIN_WATCHER (prepare, prepare)
     void set () throw () { }
   EV_END_WATCHER (prepare, prepare)
+  #endif
 
+  #if EV_CHECK_ENABLE
   EV_BEGIN_WATCHER (check, check)
     void set () throw () { }
   EV_END_WATCHER (check, check)
+  #endif
 
   #if EV_EMBED_ENABLE
   EV_BEGIN_WATCHER (embed, embed)
@@ -781,8 +793,6 @@ namespace ev {
 
   #if EV_ASYNC_ENABLE
   EV_BEGIN_WATCHER (async, async)
-    void set () throw () { }
-
     void send () throw ()
     {
       ev_async_send (EV_A_ static_cast<ev_async *>(this));
