@@ -34,21 +34,6 @@
 # define XAPPLOADDIRLOCALE	X11LIBDIR "/%s/app-defaults"
 #endif
 
-/*-------------------------------SECURITY-------------------------------*/
-
-/*
- * Default mode to restore when releasing the PTS device. It is relaxed to be
- * compatible with most systems, change it to a more secure value if your
- * system supports it (0640 for example).
- */
-#define RESTORE_TTY_MODE 0666
-
-/*
- * Define if you want to use a separate process for pty/tty handling
- * when running setuid/setgid. You need this when making it setuid/setgid.
- */
-#define PTYTTY_HELPER 1
-
 /*-----------------------SCREEN OPTIONS AND COLOURS---------------------*/
 
 /*
@@ -96,53 +81,12 @@
  */
 #define MAX_SAVELINES   10000000
 
-/*
- * Define default colours for certain items.  If you have a low colour
- * display, then consider using colours which are already pre-allocated:
- *
- *   Black		(#000000)
- *   Red3		(#CD0000)
- *   Green3		(#00CD00)
- *   Yellow3		(#CDCD00)
- *   Blue3		(#0000CD)
- *   Magenta3		(#CD00CD)
- *   Cyan3		(#00CDCD)
- *   AntiqueWhite	(#FAEBD7)
- *   Grey25		(#404040)
- *   Red		(#FF0000)
- *   Green		(#00FF00)
- *   Yellow		(#FFFF00)
- *   Blue		(#0000FF)
- *   Magenta		(#FF00FF)
- *   Cyan		(#00FFFF)
- *   White		(#FFFFFF)
- */
-/* These colours MUST be defined */
-#define COLOR_FOREGROUND	"rgb:00/00/00"
-#define COLOR_BACKGROUND	"rgb:ff/ff/ff"
-#define COLOR_SCROLLBAR		"rgb:b2/b2/b2"	/* scrollColor match Netscape */
-#define COLOR_SCROLLTROUGH	"rgb:96/96/96"
-
-/*
- * The cursor colours are special.  Be very careful about setting these:
- * foreground/background colours may be modified by command line or resources
- * prior to this allocation.  Also, they are not valid if NO_CURSORCOLOR is
- * defined
- */
-#define COLOR_CURSOR_FOREGROUND	NULL	/* if NULL, use background colour */
-#define COLOR_CURSOR_BACKGROUND	NULL	/* if NULL, use foreground colour */
-
 /*
  * Define to remove support for XCopyArea () support.  XCopyArea () is useful
  * for scrolling on non-local X displays
  */
 #define NO_SLOW_LINK_SUPPORT
 
-/*
- * Printer pipe which will be used for emulation of attached vt100 printer
- */
-#define PRINTPIPE	"lpr"
-
 /*
  * Allow 80/132 mode switching on startup
  */
@@ -150,21 +94,6 @@
 
 /*---------------------------------KEYS---------------------------------*/
 
-/*
- * Define defaults for backspace and delete keys - unless they have been
- * configured out with --disable-backspace-key / --disable-delete-key
- */
-#define DEFAULT_BACKSPACE	"DEC"		/* SPECIAL */
-#define DEFAULT_DELETE		"\033[3~"
-
-/*
- * To use
- *	Home = "\E[1~", End = "\E[4~"
- * instead of
- *	Home = "\E[7~", End = "\E[8~"	[default]
- */
-/* #define LINUX_KEYS */
-
 /*
  * Enable the keysym resource which allows you to define strings associated
  * with various KeySyms (0xFF00 - 0xFFFF).
@@ -201,7 +130,7 @@
  *      (rather than a proportion (1/5) of savedlines buffer)
  *      when paging the savedlines with SHIFT-{Prior,Next} keys.
  */
-#define PAGING_CONTEXT_LINES 1 /* */
+#define PAGING_CONTEXT_LINES 1
 
 /*
  * Have either Ctrl+Tab or Mod4+Tab emit \e\t
@@ -217,21 +146,10 @@
  */
 /* #define NO_SCROLLBAR_REPORT */
 
-/*
- * Default separating chars for multiple-click selection
- * Space and tab are separate separating characters and are not settable
- */
-#define CUTCHARS	"\"&'()*,;<=>?@[\\]^`{|}"
-
-/*
- * Add run-time support for changing the cutchars for double click selection
- */
-#define CUTCHAR_RESOURCE
-
 /*
  * Have mouse reporting include double-click info for button1
  */
-//#define MOUSE_REPORT_DOUBLECLICK
+/* #define MOUSE_REPORT_DOUBLECLICK */
 
 /*
  * Set delay between multiple click events [default: 500 milliseconds]
@@ -305,14 +223,13 @@
 #define SHADOW_WIDTH 1
 
 /*
- * When using Rxvt scrollbar, clicking above or below the slider will move
- * 1/4 of the screen height, if possible.  Setting RXVT_SCROLL_FULL will move
- * it one screen height less one line, if possible
+ * clicking above or below the scrollbar slider (all styles minus
+ * xterm) will scroll by (height - 1) rather than (height / 4).
  */
 #define RXVT_SCROLL_FULL 1
 
 /*
- * (Hops) draw an internal border line on inside edge of the scrollbar
+ * (Hops) draw an internal border line on inside edge of the rxvt scrollbar
  */
 /* #define SB_BORDER */
 
@@ -339,8 +256,8 @@
 /* #define ESCZ_ANSWER	"\033[?1;2C" */
 
 /*
- * Allow foreground/background colour to be changed with an
- * xterm escape sequence "\E]39;colour^G"
+ * Allow foreground/background colour to be changed with xterm
+ * operating system commands.
  */
 #define XTERM_COLOR_CHANGE
 
@@ -349,26 +266,6 @@
  */
 /* #define NO_SECONDARY_SCREEN_CURSOR */
 
-/*
- * Width of the term internal border
- */
-#define INTERNALBORDERWIDTH	2
-
-/*
- * Width of the term external border
- */
-#define EXTERNALBORDERWIDTH	0
-
-/*
- * Default number of extra dots between lines
- */
-#define LINESPACE	0
-
-/*
- * Default number of lines in the scrollback buffer
- */
-#define SAVELINES	1000
-
 /*
  * Provide termcap/terminfo bw support (wrap backwards on cub1)
  */
@@ -395,5 +292,86 @@
 # define LINUX_YIELD_HACK 0
 #endif
 
+/* DEFAULT RESOURCES VALUES */
+
+/*
+ * Define default colours for certain items.  If you have a low colour
+ * display, then consider using colours which are already pre-allocated:
+ *
+ *   Black		(#000000)
+ *   Red3		(#CD0000)
+ *   Green3		(#00CD00)
+ *   Yellow3		(#CDCD00)
+ *   Blue3		(#0000CD)
+ *   Magenta3		(#CD00CD)
+ *   Cyan3		(#00CDCD)
+ *   AntiqueWhite	(#FAEBD7)
+ *   Grey25		(#404040)
+ *   Red		(#FF0000)
+ *   Green		(#00FF00)
+ *   Yellow		(#FFFF00)
+ *   Blue		(#0000FF)
+ *   Magenta		(#FF00FF)
+ *   Cyan		(#00FFFF)
+ *   White		(#FFFFFF)
+ */
+/* These colours MUST be defined */
+#define COLOR_FOREGROUND	"rgb:00/00/00"
+#define COLOR_BACKGROUND	"rgb:ff/ff/ff"
+#define COLOR_SCROLLBAR		"rgb:b2/b2/b2"	/* scrollColor match Netscape */
+#define COLOR_SCROLLTROUGH	"rgb:96/96/96"
+
+/*
+ * The cursor colours are special.  Be very careful about setting these:
+ * foreground/background colours may be modified by command line or resources
+ * prior to this allocation.  Also, they are not valid if NO_CURSORCOLOR is
+ * defined
+ */
+#define COLOR_CURSOR_FOREGROUND	NULL	/* if NULL, use background colour */
+#define COLOR_CURSOR_BACKGROUND	NULL	/* if NULL, use foreground colour */
+
+/*
+ * Printer pipe which will be used for emulation of attached vt100 printer
+ */
+#define PRINTPIPE	"lpr"
+
+/*
+ * Define defaults for backspace and delete keys - unless they have been
+ * configured out with --disable-backspace-key / --disable-delete-key
+ */
+#define DEFAULT_BACKSPACE	"DEC"		/* SPECIAL */
+#define DEFAULT_DELETE		"\033[3~"
+
+/*
+ * Default separating chars for multiple-click selection
+ * Space and tab are separate separating characters and are not settable
+ */
+#define CUTCHARS	"\"&'()*,;<=>?@[\\]^`{|}"
+
+/*
+ * Width of the term internal border
+ */
+#define INTERNALBORDERWIDTH	2
+
+/*
+ * Width of the term external border
+ */
+#define EXTERNALBORDERWIDTH	0
+
+/*
+ * Default number of extra dots between lines
+ */
+#define LINESPACE	0
+
+/*
+ * Default number of extra dots between columns
+ */
+#define LETTERSPACE	0
+
+/*
+ * Default number of lines in the scrollback buffer
+ */
+#define SAVELINES	1000
+
 #endif
 
