@@ -5,6 +5,7 @@
   def (iconName)
   def (geometry)
   def (reverseVideo)
+  def (chdir)
   def (color)
   reserve (color, TOTAL_COLORS)
   def (font)
@@ -60,6 +61,7 @@
 #ifdef ENABLE_TRANSPARENCY
   def (transparent)
   def (shade)
+  def (blurradius)
 #endif
 #if XFT
   def (depth)
@@ -74,6 +76,7 @@
   def (int_bwidth)
   def (borderLess)
   def (lineSpace)
+  def (letterSpace)
   def (cursorUnderline)
   def (urgentOnBell)
 #endif
@@ -110,9 +113,12 @@
   def (perl_lib)
 #endif
 #if ISO_14755
+  def (iso14755)
   def (iso14755_52)
 #endif
 #ifdef HAVE_AFTERIMAGE
   def (blendtype)
-  def (blurradius)
+#endif
+#ifdef ENABLE_EWMH
+  def (iconfile)
 #endif
